summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--render-test/manifest_parser.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/render-test/manifest_parser.cpp b/render-test/manifest_parser.cpp
index f1884634e5..3e56138e83 100644
--- a/render-test/manifest_parser.cpp
+++ b/render-test/manifest_parser.cpp
@@ -385,8 +385,8 @@ mbgl::optional<Manifest> ManifestParser::parseManifest(const std::string& manife
continue;
}
for (auto& testPath : mbgl::filesystem::recursive_directory_iterator(path)) {
- // Skip paths that fail regexp match.
- if (!testFilter.empty() && !std::regex_match(testPath.path().string(), std::regex(testFilter))) {
+ // Skip paths that fail regexp search.
+ if (!testFilter.empty() && !std::regex_search(testPath.path().string(), std::regex(testFilter))) {
continue;
}